@@ -93,52 +93,57 @@ def CheckPMinGSMM(model, PM_df, EX_Sub_Off=['EX_glc__D_e']):
     ResultID = list()
     
     for Indx,Sub in enumerate(PM_df['BiGG'].astype(str)):
-        Sub_e = '{}_e'.format(Sub)
-        Sub_c = '{}_c'.format(Sub)
-        Sub_eIdx = np.where([Sub_e==met.id for met in model.metabolites])[0]
-        Sub_cIdx = np.where([Sub_c==met.id for met in model.metabolites])[0]
-        # testing whether biolog metabolite is extracellular or cytoplasmic
-        if Sub_cIdx.size>0 and Sub_eIdx.size>0: 
-            # metabolite is extracellular, 
-            # existence of exchange reaction unclear
-            EX_SubRct = 'EX_{}'.format(Sub_e)
-            try: 
-                model.reactions.get_by_id(EX_SubRct)
-            except KeyError:
-                with model:
-                    model.add_boundary(model.metabolites.get_by_id(Sub_e), type='exchange')
+        # first testing whether growth was detected in biolog or not
+        # if growth was detected, we give our best to check substrate metabolization, otherwise not
+        if PM_df['Growth'][Indx]:
+            Sub_e = '{}_e'.format(Sub)
+            Sub_c = '{}_c'.format(Sub)
+            Sub_eIdx = np.where([Sub_e==met.id for met in model.metabolites])[0]
+            Sub_cIdx = np.where([Sub_c==met.id for met in model.metabolites])[0]
+            # testing whether biolog metabolite is extracellular or cytoplasmic
+            if Sub_cIdx.size>0 and Sub_eIdx.size>0: 
+                # metabolite is extracellular, 
+                # existence of exchange reaction unclear
+                EX_SubRct = 'EX_{}'.format(Sub_e)
+                try: 
+                    model.reactions.get_by_id(EX_SubRct)
+                except KeyError:
+    #                with model:
+                    model.add_boundary(model.metabolites.get_by_id(Sub_e), type='exchange', lb=0, ub=1000)
+                    myGrowth = TestSubstrate(model, [EX_SubRct], EX_Sub_Off)
+                        # Substrate_list.append(myGrowth)
+        #                 print('New exchange reaction for {} with growth: {}'.format(Substrate, myGrowth))        
+                else:
                     myGrowth = TestSubstrate(model, [EX_SubRct], EX_Sub_Off)
                     # Substrate_list.append(myGrowth)
-    #                 print('New exchange reaction for {} with growth: {}'.format(Substrate, myGrowth))        
-            else:
-                myGrowth = TestSubstrate(model, [EX_SubRct], EX_Sub_Off)
-                # Substrate_list.append(myGrowth)
-
-        elif Sub_cIdx.size>0 and Sub_eIdx.size<1: 
-            # metabolite is cytoplasmic but not extracellular
-            myMet = model.metabolites.get_by_id(Sub_c)
-            myTransport = CreateTransReact(myMet)
-            EX_SubRct = 'EX_{}'.format(Sub_e)
-            with model:
+    
+            elif Sub_cIdx.size>0 and Sub_eIdx.size<1: 
+                # metabolite is cytoplasmic but not extracellular
+                myMet = model.metabolites.get_by_id(Sub_c)
+                myTransport = CreateTransReact(myMet)
+                EX_SubRct = 'EX_{}'.format(Sub_e)
+    #            with model:
                 model.add_reactions([myTransport])
-                model.add_boundary(model.metabolites.get_by_id(Sub_e), type='exchange')
+                model.add_boundary(model.metabolites.get_by_id(Sub_e), type='exchange', lb=0, ub=1000)
                 myGrowth = TestSubstrate(model, [EX_SubRct], EX_Sub_Off)
-                # Substrate_list.append(myGrowth)
-
-        # if Sub_cIdx.size<1 and Sub_eIdx.size>0:
-        #     metabolite is only extracellular (unlikely)
-        #     Substrate_list.append('Z')
-                                       
-        # if Sub_cIdx.size<1 and Sub_eIdx.size<1:
-        #     # metabolite not in GSMM
-        #     Substrate_list.append('Z')
-
+                    # Substrate_list.append(myGrowth)
+    
+            # if Sub_cIdx.size<1 and Sub_eIdx.size>0:
+            #     metabolite is only extracellular (unlikely)
+            #     Substrate_list.append('Z')
+                                           
+            # if Sub_cIdx.size<1 and Sub_eIdx.size<1:
+            #     # metabolite not in GSMM
+            #     Substrate_list.append('Z')
+    
+            else:
+                myGrowth = np.nan
         else:
-            myGrowth = np.nan
+            myGrowth = 0
             
         Substrate_list.append(myGrowth)
         ResultID.append(CheckWellinGSMM(myGrowth,PM_df.loc[Indx, 'Growth']))
-    return Substrate_list, ResultID
+    return Substrate_list, ResultID, model
 
 
 def CheckWellinGSMM(myGrowth, myBool):
